@@ -27,6 +27,7 @@ class MerchantConfiguration:
         self.key_file_path = None
         self.run_environment = None
         self.IntermediateHost = None
+        self.defaultDeveloperId = None
         self.default_headers = None
         self.key_alias = None
         self.key_password = None
@@ -48,6 +49,7 @@ class MerchantConfiguration:
         self.request_json_path_data = None
         self.solution_id = None
         self.log_config = None
+        self.__jwePEMFileDirectory = None
         self.logger = LogFactory.setup_logger(self.__class__.__name__)
 
     def set_merchant_keyid(self, value):
@@ -92,6 +94,10 @@ class MerchantConfiguration:
         if not (value.get('IntermediateHost') is None):
             self.IntermediateHost = value['IntermediateHost']
 
+    def set_defaultDeveloperId(self, value):
+        if not (value.get('defaultDeveloperId') is None):
+            self.defaultDeveloperId = value['defaultDeveloperId']
+
     def set_default_headers(self, value):
         if not (value.get('default_headers') is None):
             self.default_headers = value['default_headers']
@@ -168,6 +174,13 @@ class MerchantConfiguration:
         if not (value.get('log_config') is None):
             self.log_config = value['log_config']
 
+    def set_jwePEMFileDirectory(self, value):
+        if not (value.get('jwePEMFileDirectory') is None):
+            self.__jwePEMFileDirectory = value['jwePEMFileDirectory']
+
+    def get_jwePEMFileDirectory(self):
+        return self.__jwePEMFileDirectory
+
     # This method sets the Merchant Configuration Variables to its respective values after reading from cybs.properties
     def set_merchantconfig(self, val):
 
@@ -181,6 +194,7 @@ class MerchantConfiguration:
         self.set_portfolio_id(val)
         self.set_run_environment(val)
         self.set_IntermediateHost(val)
+        self.set_defaultDeveloperId(val)
         self.set_default_headers(val)
         self.set_merchant_id(val)
         self.set_authentication_type(val)
@@ -197,6 +211,7 @@ class MerchantConfiguration:
         self.set_access_token(val)
         self.set_refresh_token(val)
         self.set_log_configuration(val)
+        self.set_jwePEMFileDirectory(val)
 
     # Returns the time in format as defined by RFC7231
     def get_time(self):
